==> geonkick_2.9.2+dfsg.orig.tar.gz: geonkick-2.9.2/src/oscillator_envelope.h <==
/**
 * File name: oscillator_envelope.h
 * Project: Geonkick (A kick synthesizer)
 *
 * Copyright (C) 2017 Iurie Nistor (http://iuriepage.wordpress.com)
 *
 * This file is part of Geonkick.
 *
 * GeonKick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GKICK_OSCILLLATOR_ENVELOPE_H
#define GKICK_OSCILLLATOR_ENVELOPE_H

#include "envelope.h"

class Oscillator;

class OscillatorEnvelope: public Envelope
{
 public:

  OscillatorEnvelope(Oscillator* osc, const RkRect &area);
  double envelopeLengh(void) const;
  Oscillator* getOscillator() const;

 protected:
  void updatePoints() final;
  void pointAddedEvent(double x, double y) final;
  void pointUpdatedEvent(unsigned int index, double x, double y) final;
  void pointRemovedEvent(unsigned int index) final;
  double envelopeAmplitude() const final;

 private:
          Oscillator *oscillator;
};

#endif

==> geonkick_3.5.2.orig.tar.gz: geonkick-3.5.2/src/oscillator_envelope.h <==
/**
 * File name: oscillator_envelope.h
 * Project: Geonkick (A kick synthesizer)
 *
 * Copyright (C) 2017 Iurie Nistor
 *
 * This file is part of Geonkick.
 *
 * GeonKick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GKICK_OSCILLLATOR_ENVELOPE_H
#define GKICK_OSCILLLATOR_ENVELOPE_H

#include "envelope.h"

class Oscillator;

class OscillatorEnvelope: public Envelope
{
 public:

  OscillatorEnvelope(Oscillator* osc, const RkRect &area);
  double envelopeLength(void) const override;
  Oscillator* getOscillator() const;

 protected:
  void updateEnvelope() override;
  void updatePoints() override;
  void pointAddedEvent(double x, double y) override;
  void pointUpdatedEvent(unsigned int index, double x, double y) override;
  void pointRemovedEvent(unsigned int index) override;
  double envelopeAmplitude() const override;

 private:
          Oscillator *oscillator;
};

#endif
